package com.xinelu.manage.service.hospitalinfo;

import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.manage.domain.hospitalinfo.HospitalInfo;
import java.util.List;


/**
 * 医院信息管理Service接口
 *
 * @author xinyilu
 * @date 2023-02-13
 */
public interface IHospitalInfoService {
    /**
     * 查询医院信息管理
     *
     * @param id 医院信息管理主键
     * @return 医院信息管理
     */
    HospitalInfo selectHospitalInfoById(Long id);

    /**
     * 查询医院信息管理列表
     *
     * @param hospitalInfo 医院信息管理
     * @return 医院信息管理集合
     */
    List<HospitalInfo> selectHospitalInfoList(HospitalInfo hospitalInfo);

    /**
     * 新增医院信息管理
     *
     * @param hospitalInfo 医院信息管理
     * @return 结果
     */
    AjaxResult insertHospitalInfo(HospitalInfo hospitalInfo);

    /**
     * 修改医院信息管理
     *
     * @param hospitalInfo 医院信息管理
     * @return 结果
     */
    AjaxResult updateHospitalInfo(HospitalInfo hospitalInfo);

    /**
     * 批量删除医院信息管理
     *
     * @param ids 需要删除的医院信息管理主键集合
     * @return 结果
     */
    AjaxResult deleteHospitalInfoByIds(Long[] ids);

    /**
     * 删除医院信息管理信息
     *
     * @param id 医院信息管理主键
     * @return 结果
     */
    int deleteHospitalInfoById(Long id);

    /**
     * @Author mengkuiliang
     * @Description 根据家医机构编码查询医院
     * @Date 2023-10-09 009 15:46
     * @Param
     * @return
     **/
    HospitalInfo getHosptalByOrgCode(String orgCode);
}
